require 'Regiandruby/RegiInitWorkspace'
require 'Regiandruby/RegiCheckoutPackages'
require 'Regiandruby/RegiCommitPackage'
require 'Regiandruby/RegiCreatePackage'
require 'Regiandruby/RegiDeletePackage'
require 'Regiandruby/RegiAssignPackage'
require 'Regiandruby/RegiUnassignPackage'
require 'Regiandruby/RegiGeneric'
require 'Regiandruby/RegiCreateDeliveryUnit'
require 'Regiandruby/RegiDeleteDeliveryUnit'
require 'Regiandruby/RegiDeleteDeliveryUnitWithUnassign'
require 'Regiandruby/RegiExportDeliveryUnit'
require 'Regiandruby/RegiImportDeliveryUnit'
require 'Regiandruby/RegiUndeployDeliveryUnit'
require 'Regiandruby/RegiClean'
class Regiandruby
#Initializes the HANA XS Local Workspace & pulls out a default package
#
#@param pHDBUserstoreKey [String] HDB Userstore Key
#@param pUsername [String] Username
#@param pPassword [String] Password
#@param pServerLoc [String] HDB Server Location
#@param pServerPort [String] HDB Server Port
#@param pWorkspaceName [String] HANA XS Local Workspace Name
#@param pPackageName [String] Initial Package to be pulled out
#@return [Boolean] true - success; false - failure
	def self.RegiInitWorkspace (pHDBUserstoreKey,pUsername,pPassword,pServerLoc,pServerPort,pWorkspaceName,pPackageName)
		regiinitworkspace = RegiInitWorkspace.new
		regiinitworkspace.sethdbUserstoreKey(pHDBUserstoreKey)
		regiinitworkspace.setSystemDetails(pUsername,pPassword,pServerLoc,pServerPort)
		if !pPackageName.kind_of?(Array)
			regiinitworkspace.setPackageName(pPackageName)
		else
			regiinitworkspace.setPackageNames(pPackageName)
		end
		return regiinitworkspace.doExecute(pWorkspaceName)
	end

#Checks out packages to the HANA XS Local Workspace
#
#@param pHDBUserstoreKey [String] HDB Userstore Key
#@param pUsername [String] Username
#@param pPassword [String] Password
#@param pServerLoc [String] HDB Server Location
#@param pServerPort [String] HDB Server Port
#@param pWorkspaceName [String] HANA XS Local Workspace Name
#@param pPackageName [String] Initial Package to be pulled out
#@return [Boolean] true - success; false - failure	
	def self.RegiCheckoutPackages (pHDBUserstoreKey,pUsername,pPassword,pServerLoc,pServerPort,pWorkspaceName,pPackageName)
		regicheckoutpackages = RegiCheckoutPackages.new
		regicheckoutpackages.sethdbUserstoreKey(pHDBUserstoreKey)
		regicheckoutpackages.setSystemDetails(pUsername,pPassword,pServerLoc,pServerPort)
		if !pPackageName.kind_of?(Array)
			regicheckoutpackages.setPackageName(pPackageName)
		else
			regicheckoutpackages.setPackageNames(pPackageName)
		end
		return regicheckoutpackages.doExecute(pWorkspaceName)
	end

#Commits packages to the HANA XS Server
#
#@param pHDBUserstoreKey [String] HDB Userstore Key
#@param pUsername [String] Username
#@param pPassword [String] Password
#@param pServerLoc [String] HDB Server Location
#@param pServerPort [String] HDB Server Port
#@param pWorkspaceName [String] HANA XS Local Workspace Name
#@param pDeliveryUnitName [String] Delivery Unit Name
#@param pDeliveryUnitVendor [String] Delivery Unit Vendor
#@param pPackageName [String] Initial Package to be pulled out
#@param pRevertPackages [Boolean] Optional, flag for reverting packages ( true or nil)
#@param pAssignSubPackages [Boolean] Optional, flag for assigning sub packages ( true or nil)
#@return [Boolean] true - success; false - failure
	def self.RegiCommitPackage (pHDBUserstoreKey,pUsername,pPassword,pServerLoc,pServerPort,pWorkspaceName,pDeliveryUnitName,pDeliveryUnitVendor,pPackageName,pRevertPackages,pAssignSubPackages)
		regicommitpackage = RegiCommitPackage.new
		regicommitpackage.sethdbUserstoreKey(pHDBUserstoreKey)
		regicommitpackage.setSystemDetails(pUsername,pPassword,pServerLoc,pServerPort)
		regicommitpackage.setDeliveryUnit(pDeliveryUnitName)
		regicommitpackage.setDeliveryUnitVendor(pDeliveryUnitVendor)
		if !pPackageName.kind_of?(Array)
			regicommitpackage.setPackageName(pPackageName)
		else
			regicommitpackage.setPackageNames(pPackageName)
		end
		if !pRevertPackages.nil?
			regicommitpackage.doRevertPackages()
		end
		if !pAssignSubPackages.nil?
			regicommitpackage.doassignSubPackages()
		end
		return regicommitpackage.doExecute(pWorkspaceName)
	end

#Create packages in the HANA XS Local Workspace & updates the server as well
#
#@param pHDBUserstoreKey [String] HDB Userstore Key
#@param pUsername [String] Username
#@param pPassword [String] Password
#@param pServerLoc [String] HDB Server Location
#@param pServerPort [String] HDB Server Port
#@param pWorkspaceName [String] HANA XS Local Workspace Name
#@param pDeliveryUnitName [String] Delivery Unit Name
#@param pDeliveryUnitVendor [String] Delivery Unit Vendor
#@param pPackageName [Array[String]] Initial Package to be pulled out
#@return [Boolean] true - success; false - failure		
	def self.RegiCreatePackage (pHDBUserstoreKey,pUsername,pPassword,pServerLoc,pServerPort,pWorkspaceName,pDeliveryUnitName,pDeliveryUnitVendor,pPackageName)
		regicreatepackage = RegiCreatePackage.new
		regicreatepackage.sethdbUserstoreKey(pHDBUserstoreKey)
		regicreatepackage.setSystemDetails(pUsername,pPassword,pServerLoc,pServerPort)
		regicreatepackage.setDeliveryUnit(pDeliveryUnitName)
		regicreatepackage.setDeliveryUnitVendor(pDeliveryUnitVendor)
		if !pPackageName.kind_of?(Array)
			regicreatepackage.setPackageName(pPackageName)
		else
			regicreatepackage.setPackageNames(pPackageName)
		end
		return regicreatepackage.doExecute(pWorkspaceName)
	end

#Deletes packages in HANA Server
#
#@param pHDBUserstoreKey [String] HDB Userstore Key
#@param pUsername [String] Username
#@param pPassword [String] Password
#@param pServerLoc [String] HDB Server Location
#@param pServerPort [String] HDB Server Port
#@param pWorkspaceName [String] HANA XS Local Workspace Name
#@param pPackageName [String] Initial Package to be pulled out
#@return [Boolean] true - success; false - failure
	def self.RegiDeletePackage (pHDBUserstoreKey,pUsername,pPassword,pServerLoc,pServerPort,pWorkspaceName,pPackageName)
		regideletepackage = RegiDeletePackage.new
		regideletepackage.sethdbUserstoreKey(pHDBUserstoreKey)
		regideletepackage.setSystemDetails(pUsername,pPassword,pServerLoc,pServerPort)
		if !pPackageName.kind_of?(Array)
			regideletepackage.setPackageName(pPackageName)
		else
			regideletepackage.setPackageNames(pPackageName)
		end
		return regideletepackage.doExecute(pWorkspaceName)
	end

#Assigns packages to delivery unit
#
#@param pHDBUserstoreKey [String] HDB Userstore Key
#@param pUsername [String] Username
#@param pPassword [String] Password
#@param pServerLoc [String] HDB Server Location
#@param pServerPort [String] HDB Server Port
#@param pWorkspaceName [String] HANA XS Local Workspace Name
#@param pDeliveryUnitName [String] Delivery Unit Name
#@param pDeliveryUnitVendor [String] Delivery Unit Vendor
#@param pPackageName [String] Initial Package to be pulled out
#@return [Boolean] true - success; false - failure
	def self.RegiAssignPackage (pHDBUserstoreKey,pUsername,pPassword,pServerLoc,pServerPort,pWorkspaceName,pDeliveryUnitName,pDeliveryUnitVendor,pPackageName)
		regiassignpackage = RegiAssignPackage.new
		regiassignpackage.sethdbUserstoreKey(pHDBUserstoreKey)
		regiassignpackage.setSystemDetails(pUsername,pPassword,pServerLoc,pServerPort)
		regiassignpackage.setDeliveryUnit(pDeliveryUnitName)
		regiassignpackage.setDeliveryUnitVendor(pDeliveryUnitVendor)
		if !pPackageName.kind_of?(Array)
			regiassignpackage.setPackageName(pPackageName)
		else
			regiassignpackage.setPackageNames(pPackageName)
		end
		return regiassignpackage.doExecute(pWorkspaceName)
	end


#Unassigns packages to delivery unit
#
#@param pHDBUserstoreKey [String] HDB Userstore Key
#@param pUsername [String] Username
#@param pPassword [String] Password
#@param pServerLoc [String] HDB Server Location
#@param pServerPort [String] HDB Server Port
#@param pWorkspaceName [String] HANA XS Local Workspace Name
#@param pDeliveryUnitName [String] Delivery Unit Name
#@param pDeliveryUnitVendor [String] Delivery Unit Vendor
#@param pPackageName [String] Initial Package to be pulled out
#@return [Boolean] true - success; false - failure
	def self.RegiUnassignPackage (pHDBUserstoreKey,pUsername,pPassword,pServerLoc,pServerPort,pWorkspaceName,pDeliveryUnitName,pDeliveryUnitVendor,pPackageName)
		regiunassignpackage = RegiUnassignPackage.new
		regiunassignpackage.sethdbUserstoreKey(pHDBUserstoreKey)
		regiunassignpackage.setSystemDetails(pUsername,pPassword,pServerLoc,pServerPort)
		regiunassignpackage.setDeliveryUnit(pDeliveryUnitName)
		regiunassignpackage.setDeliveryUnitVendor(pDeliveryUnitVendor)
		if !pPackageName.kind_of?(Array)
			regiunassignpackage.setPackageName(pPackageName)
		else
			regiunassignpackage.setPackageNames(pPackageName)
		end
		return regiunassignpackage.doExecute(pWorkspaceName)
	end

#Create delivery unit
#
#@param pHDBUserstoreKey [String] HDB Userstore Key
#@param pUsername [String] Username
#@param pPassword [String] Password
#@param pServerLoc [String] HDB Server Location
#@param pServerPort [String] HDB Server Port
#@param pWorkspaceName [String] HANA XS Local Workspace Name
#@param pDeliveryUnitName [String] Delivery Unit Name
#@param pDeliveryUnitVendor [String] Delivery Unit Vendor
#@param pDeliveryUnitVersion [String] Delivery Unit Version
#@param pDeliveryUnitVersionSP [String] Delivery Unit Version SP
#@param pDeliveryUnitVersionPatch [String] Delivery Unit Version Patch
#@param pDeliveryUnitResponsible [String] Delivery Unit Responsible
#@param pDeliveryUnitACH [String]
#@param pDeliveryUnitCaption [String]
#@param pDeliveryUnitPPMSId [String]
#@param pDeliveryUnitSpPPMSId [String]
#@return [Boolean] true - success; false - failure
	def self.RegiCreateDeliveryUnit (pHDBUserstoreKey,pUsername,pPassword,pServerLoc,pServerPort,pWorkspaceName,pDeliveryUnitName,pDeliveryUnitVendor,pDeliveryUnitVersion,pDeliveryUnitVersionSP,pDeliveryUnitVersionPatch,pDeliveryUnitResponsible,pDeliveryUnitACH,pDeliveryUnitCaption,pDeliveryUnitPPMSId,pDeliveryUnitSpPPMSId)
		regicreatedeliveryunit = RegiCreateDeliveryUnit.new
		regicreatedeliveryunit.sethdbUserstoreKey(pHDBUserstoreKey)
		regicreatedeliveryunit.setSystemDetails(pUsername,pPassword,pServerLoc,pServerPort)
		regicreatedeliveryunit.setDeliveryUnit(pDeliveryUnitName)
		regicreatedeliveryunit.setDeliveryUnitVendor(pDeliveryUnitVendor)
		regicreatedeliveryunit.setDeliveryUnitVersion(pDeliveryUnitVersion)
		regicreatedeliveryunit.setDeliveryUnitVersionSP(pDeliveryUnitVersionSP)
		regicreatedeliveryunit.setDeliveryUnitVersionPatch(pDeliveryUnitVersionPatch)
		regicreatedeliveryunit.setDeliveryUnitResponsible(pDeliveryUnitResponsible)
		regicreatedeliveryunit.setDeliveryUnitACH(pDeliveryUnitACH)
		regicreatedeliveryunit.setDeliveryUnitCaption(pDeliveryUnitCaption)
		regicreatedeliveryunit.setDeliveryUnitPPMSId(pDeliveryUnitPPMSId)
		regicreatedeliveryunit.setDeliveryUnitSpPPMSId(pDeliveryUnitSpPPMSId)
		return regicreatedeliveryunit.doExecute(pWorkspaceName)
	end

#Delete delivery unit
#
#@param pHDBUserstoreKey [String] HDB Userstore Key
#@param pUsername [String] Username
#@param pPassword [String] Password
#@param pServerLoc [String] HDB Server Location
#@param pServerPort [String] HDB Server Port
#@param pWorkspaceName [String] HANA XS Local Workspace Name
#@param pDeliveryUnitName [String] Delivery Unit Name
#@param pDeliveryUnitVendor [String] Delivery Unit Vendor
#@return [Boolean] true - success; false - failure
	def self.RegiDeleteDeliveryUnit (pHDBUserstoreKey,pUsername,pPassword,pServerLoc,pServerPort,pWorkspaceName,pDeliveryUnitName,pDeliveryUnitVendor)
		regideletedeliveryunit = RegiDeleteDeliveryUnit.new
		regideletedeliveryunit.sethdbUserstoreKey(pHDBUserstoreKey)
		regideletedeliveryunit.setSystemDetails(pUsername,pPassword,pServerLoc,pServerPort)
		regideletedeliveryunit.setDeliveryUnit(pDeliveryUnitName)
		regideletedeliveryunit.setDeliveryUnitVendor(pDeliveryUnitVendor)
		return regideletedeliveryunit.doExecute(pWorkspaceName)
	end

#Delete delivery unit unassigning all packages
#
#@param pHDBUserstoreKey [String] HDB Userstore Key
#@param pUsername [String] Username
#@param pPassword [String] Password
#@param pServerLoc [String] HDB Server Location
#@param pServerPort [String] HDB Server Port
#@param pWorkspaceName [String] HANA XS Local Workspace Name
#@param pDeliveryUnitName [String] Delivery Unit Name
#@param pDeliveryUnitVendor [String] Delivery Unit Vendor
#@return [Boolean] true - success; false - failure
	def self.RegiDeleteDeliveryUnitWithUnassign (pHDBUserstoreKey,pUsername,pPassword,pServerLoc,pServerPort,pWorkspaceName,pDeliveryUnitName,pDeliveryUnitVendor)
		regideletedeliveryunitwithunassign = RegiDeleteDeliveryUnitWithUnassign.new
		regideletedeliveryunitwithunassign.sethdbUserstoreKey(pHDBUserstoreKey)
		regideletedeliveryunitwithunassign.setSystemDetails(pUsername,pPassword,pServerLoc,pServerPort)
		regideletedeliveryunitwithunassign.setDeliveryUnit(pDeliveryUnitName)
		regideletedeliveryunitwithunassign.setDeliveryUnitVendor(pDeliveryUnitVendor)
		return regideletedeliveryunitwithunassign.doExecute(pWorkspaceName)
	end

#Export Delivery Unit
#
#@param pHDBUserstoreKey [String] HDB Userstore Key
#@param pUsername [String] Username
#@param pPassword [String] Password
#@param pServerLoc [String] HDB Server Location
#@param pServerPort [String] HDB Server Port
#@param pWorkspaceName [String] HANA XS Local Workspace Name
#@param pDeliveryUnitName [String] Delivery Unit Name
#@param pDeliveryUnitVendor [String] Delivery Unit Vendor
#@param pDeliveryUnitVersion [String] Delivery Unit Version
#@param pDeliveryUnitVersionSP [String] Delivery Unit Version SP
#@param pDeliveryUnitVersionPatch [String] Delivery Unit Version Patch
#@param pDeliveryUnitFileName [String] Delivery Unit File Name
#@param pNameVersionSeparator [String]
#@param pAlias [String]
#@param pTargetFolderName [String]
#@return [Boolean] true - success; false - failure
	def self.RegiExportDeliveryUnit (pHDBUserstoreKey,pUsername,pPassword,pServerLoc,pServerPort,pWorkspaceName,pDeliveryUnitName,pDeliveryUnitVendor,pDeliveryUnitVersion,pDeliveryUnitVersionSP,pDeliveryUnitVersionPatch,pDeliveryUnitFileName,pNameVersionSeparator,pAlias,pTargetFolderName)
		regiexportdeliveryunit = RegiExportDeliveryUnit.new
		regiexportdeliveryunit.sethdbUserstoreKey(pHDBUserstoreKey)
		regiexportdeliveryunit.setSystemDetails(pUsername,pPassword,pServerLoc,pServerPort)
		regiexportdeliveryunit.setDeliveryUnit(pDeliveryUnitName)
		regiexportdeliveryunit.setDeliveryUnitVendor(pDeliveryUnitVendor)
		regiexportdeliveryunit.setDeliveryUnitVersion(pDeliveryUnitVersion)
		regiexportdeliveryunit.setDeliveryUnitVersionSP(pDeliveryUnitVersionSP)
		regiexportdeliveryunit.setDeliveryUnitVersionPatch(pDeliveryUnitVersionPatch)
		regiexportdeliveryunit.setDeliveryUnitFileName(pDeliveryUnitFileName)
		regiexportdeliveryunit.setNameVersionSeparator(pNameVersionSeparator)
		regiexportdeliveryunit.setAlias(pAlias)
		regiexportdeliveryunit.setTargetFolderName(pTargetFolderName)
		return regiexportdeliveryunit.doExecute(pWorkspaceName)
	end

#Export Delivery Unit
#
#@param pHDBUserstoreKey [String] HDB Userstore Key
#@param pUsername [String] Username
#@param pPassword [String] Password
#@param pServerLoc [String] HDB Server Location
#@param pServerPort [String] HDB Server Port
#@param pWorkspaceName [String] HANA XS Local Workspace Name
#@param pDeliveryUnitName [String] Delivery Unit Name
#@param pDeliveryUnitVendor [String] Delivery Unit Vendor
#@param pDeliveryUnitVersion [String] Delivery Unit Version
#@param pDeliveryUnitVersionSP [String] Delivery Unit Version SP
#@param pDeliveryUnitVersionPatch [String] Delivery Unit Version Patch
#@param pUpdate [String]
#@param pDeliveryUnitFileName [String] Delivery Unit File Name
#@param pNameVersionSeparator [String]
#@param pUseSnapshot [Boolean], Optional
#@param pVerbose [Boolean], Optional
#@param pLog [Boolean], Optional
#@param pForceRemove [Boolean], Optional
#@param pAutoActivate [Boolean], Optional
#@return [Boolean] true - success; false - failure
	def self.RegiImportDeliveryUnit (pHDBUserstoreKey,pUsername,pPassword,pServerLoc,pServerPort,pWorkspaceName,pDeliveryUnitName,pDeliveryUnitVendor,pDeliveryUnitVersion,pDeliveryUnitVersionSP,pDeliveryUnitVersionPatch,pUpdate,pDeliveryUnitFileName,pNameVersionSeparator,pUseSnapshot,pVerbose,pLog,pForceRemove,pAutoActivate)
		regiimportdeliveryunit = RegiImportDeliveryUnit.new
		regiimportdeliveryunit.sethdbUserstoreKey(pHDBUserstoreKey)
		regiimportdeliveryunit.setSystemDetails(pUsername,pPassword,pServerLoc,pServerPort)
		regiimportdeliveryunit.setDeliveryUnit(pDeliveryUnitName)
		regiimportdeliveryunit.setDeliveryUnitVendor(pDeliveryUnitVendor)
		regiimportdeliveryunit.setDeliveryUnitVersion(pDeliveryUnitVersion)
		regiimportdeliveryunit.setDeliveryUnitVersionSP(pDeliveryUnitVersionSP)
		regiimportdeliveryunit.setDeliveryUnitVersionPatch(pDeliveryUnitVersionPatch)
		regiimportdeliveryunit.setDeliveryUnitFileName(pDeliveryUnitFileName)
		regiimportdeliveryunit.setNameVersionSeparator(pNameVersionSeparator)
		if !pUseSnapshot.nil?
			regiimportdeliveryunit.setUseSnapshot()
		end
		if !pUpdate.nil?
			regiimportdeliveryunit.setUpdate()
		end
		if !pVerbose.nil?
			regiimportdeliveryunit.setVerbose()
		end
		if !pLog.nil?
			regiimportdeliveryunit.setLog()
		end
		if !pForceRemove.nil?
			regiimportdeliveryunit.setForceRemove()
		end
		if !pAutoActivate.nil?
			regiimportdeliveryunit.setAutoActivate()
		end
		return regiimportdeliveryunit.doExecute(pWorkspaceName)
	end

#Undeploy Delivery Unit
#
#@param pHDBUserstoreKey [String] HDB Userstore Key
#@param pUsername [String] Username
#@param pPassword [String] Password
#@param pServerLoc [String] HDB Server Location
#@param pServerPort [String] HDB Server Port
#@param pWorkspaceName [String] HANA XS Local Workspace Name
#@param pDeliveryUnitName [String] Delivery Unit Name
#@param pDeliveryUnitVendor [String] Delivery Unit Vendor
#@param pVerbose [Boolean], Optional
#@return [Boolean] true - success; false - failure
	def self.RegiUndeployDeliveryUnit (pHDBUserstoreKey,pUsername,pPassword,pServerLoc,pServerPort,pWorkspaceName,pDeliveryUnitName,pDeliveryUnitVendor,pVerbose)
		regiundeploydeliveryunit = RegiUndeployDeliveryUnit.new
		regiundeploydeliveryunit.sethdbUserstoreKey(pHDBUserstoreKey)
		regiundeploydeliveryunit.setSystemDetails(pUsername,pPassword,pServerLoc,pServerPort)
		regiundeploydeliveryunit.setDeliveryUnit(pDeliveryUnitName)
		regiundeploydeliveryunit.setDeliveryUnitVendor(pDeliveryUnitVendor)
		if !pVerbose.nil?
			regiundeploydeliveryunit.setVerbose()
		end
		return regiundeploydeliveryunit.doExecute(pWorkspaceName)
	end

#Regi Generic - Any command can be executed
#
#@param pHDBUserstoreKey [String] HDB Userstore Key
#@param pUsername [String] Username
#@param pPassword [String] Password
#@param pServerLoc [String] HDB Server Location
#@param pServerPort [String] HDB Server Port
#@param pWorkspaceName [String] HANA XS Local Workspace Name
#@param pRegiAction [String] Regi Action
#@param pVerbose [Boolean], Optional
#@param pRegiArgs [String] Regi Arguments
#@return [Boolean] true - success; false - failure
	def self.RegiGeneric (pHDBUserstoreKey,pUsername,pPassword,pServerLoc,pServerPort,pWorkspaceName,pRegiAction,pVerbose,pRegiArgs)
		regigeneric = RegiGeneric.new
		regigeneric.sethdbUserstoreKey(pHDBUserstoreKey)
		regigeneric.setSystemDetails(pUsername,pPassword,pServerLoc,pServerPort)
		regigeneric.setRegiAction(pRegiAction)
		if !pVerbose.nil?
			regigeneric.setVerbose()
		end
		regigeneric.setRegiArgs(pRegiArgs)
		return regigeneric.doExecute(pWorkspaceName)
	end

#Clean Packages & Delivery Units
#
#@param pHDBUserstoreKey [String] HDB Userstore Key
#@param pUsername [String] Username
#@param pPassword [String] Password
#@param pServerLoc [String] HDB Server Location
#@param pServerPort [String] HDB Server Port
#@param pWorkspaceName [String] HANA XS Local Workspace Name
#@param pDeliveryUnitName [String] Delivery Unit Name
#@param pDeliveryUnitVendor [String] Delivery Unit Vendor
#@param pCleanDeliveryUnit [Boolean], Optional
#@return [Boolean] true - success; false - failure
	def self.RegiClean (pHDBUserstoreKey,pUsername,pPassword,pServerLoc,pServerPort,pWorkspaceName,pDeliveryUnitName,pDeliveryUnitVendor,pPackageName,pCleanDeliveryUnit)
		regiclean = RegiClean.new
		regiclean.sethdbUserstoreKey(pHDBUserstoreKey)
		regiclean.setSystemDetails(pUsername,pPassword,pServerLoc,pServerPort)
		regiclean.setDeliveryUnit(pDeliveryUnitName)
		regiclean.setDeliveryUnitVendor(pDeliveryUnitVendor)
		if !pPackageName.kind_of?(Array)
			regiclean.setPackageName(pPackageName)
		else
			regiclean.setPackageNames(pPackageName)
		end
		if !pCleanDeliveryUnit.nil?
			regiclean.setCleanDeliveryUnit()
		end
		return regiclean.doExecute(pWorkspaceName)
	end
end